Enumeration
AdapResponseAppearance
since: 1.2
Description [src]
Describes the possible styles of AdapAlertDialog response buttons.
Available since: 1.2
Members
-
ADAP_RESPONSE_DEFAULT -
The default appearance.
- Value:
0 - Available since: 1.2
- Value:
-
ADAP_RESPONSE_SUGGESTED -
Used to denote important responses such as the affirmative action.
- Value:
1 - Available since: 1.2
- Value:
-
ADAP_RESPONSE_DESTRUCTIVE -
Used to draw attention to the potentially damaging consequences of using the response. This appearance acts as a warning to the user.
- Value:
2 - Available since: 1.2
- Value: